<?php
namespace app\cms\event;

class Sql
{
    /**
    * 安装时触发
    * @return bool 只有返回true时才会往下执行
    */
	public function install()
    {
        //批量添加配置
        $this->insertConfig();
        
        //批量添加路由
        $this->insertRoute();
        
        //批量添加权限
        $this->insertAuth();
        
        //批量添加分类/标签/导航
        $this->insertTerm();
        
        //返回结果
        return true;
	}
    
    /**
    * 升级时触发
    * @return bool 只有返回true时才会往下执行
    */
    public function upgrade()
    {
        \think\Db::execute("update dc_info_meta set info_meta_key='cms_top' where info_meta_key='article_top';"); 
        
        \think\Db::execute("update dc_info_meta set info_meta_key='cms_recommend' where info_meta_key='article_recommend';");
        
        \think\Db::execute("update dc_info_meta set info_meta_key='cms_head' where info_meta_key='article_head';");
        
        \think\Db::execute("update dc_info_meta set info_meta_key='cms_fast' where info_meta_key='article_fast';");
        
        \think\Db::execute("update dc_info_meta set info_meta_key='cms_color' where info_meta_key='info_color';");
        
        \think\Db::execute("update dc_info_meta set info_meta_key='cms_cover' where info_meta_key='info_cover';");
        
        \think\Db::execute("update dc_info_meta set info_meta_key='cms_slide' where info_meta_key='info_slide';");
        
        \think\Db::execute("update dc_info_meta set info_meta_key='cms_up' where info_meta_key='info_up';");
        
        \think\Db::execute("update dc_info_meta set info_meta_key='cms_down' where info_meta_key='info_down';");
        
        \think\Db::execute("update dc_info_meta set info_meta_key='cms_referer' where info_meta_key='info_referer';");
        
        \think\Db::execute("update dc_info_meta set info_meta_key='cms_letter' where info_meta_key='info_letter';");
        
        \think\Db::execute("update dc_info_meta set info_meta_key='cms_tpl' where info_meta_key='info_tpl';");
        
        //更新基础信息
        \daicuo\Apply::updateStatus('cms', 'enable');

        //更新打包配置
        if(config('common.apply_module') == 'cms'){
            \daicuo\Op::write([
                'apply_version' => '1.2.23',
            ]);
        }
        
        //更新配置
        \daicuo\Op::write([
            'limit_default'     => 10,
            'limit_index'       => 10,
            'limit_search'      => 10,
            'limit_sitemap'     => 100,
            'limit_tag_index'   => 10,
            'limit_tag_all'     => 60,
        ],'cms','config','system',0,'yes');
        
        //删除无效文件
        $this->deleteFiles();

        return true;
    }
    
    /**
    * 卸载时触发
    * @return bool 只有返回true时才会往下执行
    */
    public function remove()
    {
        //删除插件配置
        \daicuo\Op::delete_module('cms');
        //删除默认(分类/标签)
        foreach( DcTermSelect(['field'=>'term_id,term_name','name'=>['in','分类测试,标签测试'],'module'=>'cms','with'=>'']) as $key=>$value){
            DcTermDeleteId($value['term_id']);
        }
        //返回结果
        return true;
    }
    
    /**
    * 删除时触发
    * @return bool 只有返回true时才会往下执行
    */
    public function unInstall()
    {
        
        //删除插件配置
        \daicuo\Op::delete_module('cms');
        //删除插件分类与导航菜单（不删除标签）
        foreach( DcTermSelect(['field'=>'term_id,term_name','type'=>['in','category,navs'],'module'=>'cms','with'=>'']) as $key=>$value){
            DcTermDeleteId($value['term_id']);
        }
        //返回结果
        return true;
	}
    
    //批量添加初始配置
    private function insertConfig()
    {
        return \daicuo\Op::write([
            'theme'             => 'default',
            'theme_wap'         => 'default',
            'index_title'       => '呆错文章管理系统',
            'index_keywords'    => '新闻发布系统,文章管理系统,文章系统,文章CMS,新闻CMS',
            'index_description' => '呆错文章系统是一款基于呆错后台开发框架研发的文章管理系统，被广泛应用于搭建博客、行业站、企业站、产品展示等。',
            'slug_first'        => 1,
            'request_max'       => 0,
            'search_interval'   => 0,
            'search_hot'        => '',
            'search_list'       => 'index,baidu,sogou,toutiao,bing,so',
            'rewrite_index'     => '/cms$',
            'limit_default'     => 10,
            'limit_index'       => 10,
            'limit_search'      => 10,
            'limit_sitemap'     => 100,
            'limit_tag_index'   => 10,
            'limit_tag_all'     => 60,
        ],'cms','config','system',0,'yes');
    }
    
    //批量添加路由
    private function insertRoute()
    {
        return \daicuo\Route::save_all([
            [
                'rule'        => '/cms$',
                'address'     => 'cms/index/index',
                'method'      => '*',
                'op_module'   => 'cms',
                'op_controll' => 'route',
                'op_action'   => 'system',
            ],
        ]);
    }
    
    //批量添加初始权限
    private function insertAuth()
    {
        \daicuo\Op::delete_all(['op_module'=>'cms','op_controll'=>'auth','op_action'=>'system']);
        
        return \daicuo\Op::save_all([
            [
                'op_name'       => 'guest',
                'op_value'      => 'cms/index/index',
                'op_module'     => 'cms',
                'op_controll'   => 'auth',
                'op_action'     => 'system',
                'op_order'      => 0,
                'op_status'     => 'normal',
            ],
        ]);
    }
    
    //批量添加分类/标签/导航
    private function insertTerm()
    {
        //DcConfigMerge('custom_fields.term_meta', ['navs_target','navs_url','navs_image','navs_active','navs_class']);
        
        return \daicuo\Term::save_all([
            [
                'term_name'       => '分类测试',
                'term_slug'       => 'categorytest',
                'term_module'     => 'cms',
                'term_controll'   => 'category',
                'term_action'     => 'index',
                'term_status'     => 'normal',
                'term_order'      => 0,
                'term_parent'     => 0,
                'term_type'       => 'category',
                'term_navbar'     => 'yes',
                'term_info'       => '我是分类测试的说明，后台>系统>分类管理',
                'term_tpl'        => 'index',
            ],
            [
                'term_name'       => '标签测试',
                'term_slug'       => 'tagtest',
                'term_module'     => 'cms',
                'term_controll'   => 'tag',
                'term_action'     => 'index',
                'term_status'     => 'normal',
                'term_order'      => 0,
                'term_parent'     => 0,
                'term_type'       => 'tag',
                'term_navbar'     => 'no',
                'term_info'       => '我是标签测试的说明，后台>系统>标签管理',
                'term_tpl'        => 'index',
            ]
        ]);
    }
    
    //删除旧文件
    private function deleteFiles()
    {
        $file = new \files\File();
        $file->d_delete('./apps/cms/view/article/');
        $file->d_delete('./apps/cms/view/friend/');
        $file->f_delete('./apps/cms/event/Article.php');
        $file->f_delete('./apps/cms/event/Friend.php');
        $file->f_delete('./apps/cms/validate/Article.php');
        $file->f_delete('./apps/cms/loglic/Friend.php');
        $file->f_delete('./apps/cms/theme/default/index/categorys.tpl');
        $file->f_delete('./apps/cms/theme/default/index/tags.tpl');
    }
}