<?php
namespace app\cms\loglic;

class Common
{
    // 错误信息
    protected $error = '';
    
    /**
     * 获取错误信息
     * @return mixed
     */
    public function getError()
    {
        return $this->error;
    }
    
    /**
    * 添加文章高级用法（自定义场景与规则）
    * @version 1.0.0 首次引入
    * @param array $post 必需;数组格式,支持的字段列表请参考手册
    * @param bool $autoTerm 必需;当分类与标签不存在时是否自动新增;默认:false
    * @param string $action 必需;新增或修改(save|update);默认:save
    * @param string $scene 可选;验证场景(save|update|slugUnique|refererUnique);默认:slugUnique
    * @param array $sceneRule 可选;自定义验证规则;默认:无
    * @param array $slugRule 可选;别名规则;默认:false
    * @return mixed 成功时返回obj,失败时null
    */
    public function write($post=[], $autoTerm=false, $action='save', $scene='slugUnique', $sceneRule=[], $slugRule=false)
    {
        //数据格式化（修改器）
        $post = DcArrayArgs($post,[
            'info_module'   => 'cms',
            'info_controll' => 'detail',
            'info_action'   => 'index',
            'info_staus'    => 'normal',
            'info_type'     => 'index',
        ]);
        $post = cmsDataSet($post, $autoTerm);

        //取消框架模块验证
        config('common.validate_name', false);
        config('common.validate_scene', false);
        //自定义验证器与验证规则
        if($scene){
            //实例化验证器
            $validate = validate('cms/Detail', 'validate');
            //自定义验证场景规则
            if($sceneRule){
                $validate->scene($scene, $sceneRule);
            }
            //表单验证结果（失败）
            if(!$validate->scene($scene)->check($post)){
                $this->error = $validate->getError();
                return null;
            }
        }

        //定义框架别名处理规则（默认取消别名检测false）
        config('common.where_slug_unique', $slugRule);
        //config('common.where_slug_unique',['info_module'=>['eq','cms'],'info_controll'=>['eq','detail']]);
        //调用数据库接口
        if($action == 'save'){
            return \daicuo\Info::save($post, 'info_meta,term_map');
        }else if($action == 'update'){
            return DcArrayResult(\daicuo\Info::update_id($post['info_id'], $post, 'info_meta,term_map'));
        }
        //默认返回
        return null;
    }
}